;Filename: Putchar.s
;Part    : ADuC703x.
;Created : 14/04/2006
;Author  : Patrick Noonan (Analog Device Inc.)
;This file is in beta sampling.

;This software is supplied subject our standard software license agreement.
;A non-binding summary is as follows:
;"You may use the software in your own code at your own risk.
;" ADI inc disclaims any warranty or liability of its use".
;The full standard software license agreement is available on request and
; remains the binding agreement.

#include        <ADuC7030.inc>

; putchar==========UART put character.
; C Function prototype: int putchar(int iTx);
;iTx:{}
; Description of Function: Writes iTx to the UART for transmission.
; User interface:
;   Put value to send in iTx.
;   Call putchar. Will wait untill buffer not full then output iTx.
;   Returns iTx in r0 always.
; Robustness:
;   UART must be configured before writing data.
;   Waits as long as UART is full.
; Side effects: Corrupts r1 and r3.

                RSEG CODE
                MODULE putchar
                PUBLIC putchar
                CODE32

putchar:
         mov     r3,#0xff0000             ;r3 = Z_BASE;
         orr     r3,r3,#0xff000000
PcLoop1: ldr     r1,[r3,#Z_COMSTA0]       ;while(COMSTA.6);
         ands    r1,r1,#0x040
         beq     PcLoop1
         str     r0,[r3,#Z_COMTX]         ;COMTX = iTx;
PcLoop2: ldr     r1,[r3,#Z_COMSTA0]       ;while(COMSTA.6);
         ands    r1,r1,#0x040
         beq     PcLoop2
         cmp     r0,#0x0A                 ;Compare r0 with '\n'
         moveq   r1,#0x0D                 ; Move 0D into r1
         streq   r1,[r3,#Z_COMTX]         ; COMTX = 0x0D;
         bx      lr                       ;return r0.
                        

                 ENDMOD  putchar

                 END

